@@ -6,7 +6,7 @@ from enum import Enum
 from alembic.config import Config
 from alembic import command
 
-alembic_cfg = Config("/path/to/yourapp/alembic.ini")
+alembic_cfg = Config()
 
 cli = typer.Typer()
 
